==> qore-1.11.0.tar.bz2: qore-1.11.0/docs/modules/AwsRestClientDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "AwsRestClientDataProvider", "namespace_aws_rest_client_data_provider.html", [
      [ "AwsRestClientCallDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_call_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_call_data_provider" ],
      [ "AwsRestClientDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider" ],
      [ "AwsRestClientDataProviderFactory", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider_factory.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider_factory" ],
      [ "AwsRestClientDeleteDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_delete_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_delete_data_provider" ],
      [ "AwsRestClientGetDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_get_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_get_data_provider" ],
      [ "AwsRestClientHeadDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_head_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_head_data_provider" ],
      [ "AwsRestClientOptionsDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_options_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_options_data_provider" ],
      [ "AwsRestClientPatchDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_patch_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_patch_data_provider" ],
      [ "AwsRestClientPostDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_post_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_post_data_provider" ],
      [ "AwsRestClientPutDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_put_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_put_data_provider" ]
    ] ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/AwsRestClientDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "AwsRestClientDataProvider", "namespace_aws_rest_client_data_provider.html", [
      [ "AwsRestClientCallDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_call_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_call_data_provider" ],
      [ "AwsRestClientDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider" ],
      [ "AwsRestClientDataProviderBase", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider_base.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider_base" ],
      [ "AwsRestClientDataProviderFactory", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider_factory.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_data_provider_factory" ],
      [ "AwsRestClientDeleteDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_delete_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_delete_data_provider" ],
      [ "AwsRestClientGetDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_get_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_get_data_provider" ],
      [ "AwsRestClientHeadDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_head_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_head_data_provider" ],
      [ "AwsRestClientOptionsDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_options_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_options_data_provider" ],
      [ "AwsRestClientPatchDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_patch_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_patch_data_provider" ],
      [ "AwsRestClientPostDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_post_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_post_data_provider" ],
      [ "AwsRestClientPutDataProvider", "class_aws_rest_client_data_provider_1_1_aws_rest_client_put_data_provider.html", "class_aws_rest_client_data_provider_1_1_aws_rest_client_put_data_provider" ]
    ] ]
];
